ComputationCache<K, V> class

A cache for uniting computations by a key.

Constructors

ComputationCache({bool memoized = true, bool assertIdempotent = true, void dispose(V value)?, void onCancel()?})
Constructs an empty cache. The configs are as with Computed.new.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
wrap(K key, V computation()) → Computed<V>
Returns a computation that creates and uses a leader for the given key.

Operators

operator ==(Object other) → bool
The equality operator.
inherited